package com.symantec.vip.ssl;

import com.sun.xml.internal.ws.developer.JAXWSProperties;
import com.symantec.vip.ws.vipuserservices.GetServerTimeRequestType;
import com.symantec.vip.ws.vipuserservices.GetServerTimeResponseType;
import com.symantec.vip.ws.vipuserservices.QueryService;
import com.symantec.vip.ws.vipuserservices.QueryServicePort;

import javax.net.ssl.SSLContext;
import javax.xml.ws.BindingProvider;
import java.io.File;
import java.math.BigInteger;
import java.net.MalformedURLException;
import java.net.URL;
import java.util.logging.Logger;

/**
 * Before running this test client, please make sure you have built the VIP User Services WSDL.
 *
 * Created by roy_antonyraj on 3/9/15.
 */
public class TestClient {
    private static final Logger logger = Logger.getLogger(TestClient.class.getName());

    // FIXME Replace this path and password with your P12 path and password.
    public static final String KEY_STORE_PATH = "/Users/roy_antonyraj/tmp/dev.p12";
    public static final String KEY_STORE_PASSWORD = "Password1";

    // FIXME Replace this with production or pilot environment URL.
    public static final String VIPUS_BASE_URL = "https://dev-vipuserservices-auth.bbtest.net";
    public static final String QUERY_SERVICE_URL = VIPUS_BASE_URL +
            "/vipuserservices/QueryService_1_3";

    // FIXME Replace this with the path where you have downloaded and stored the WSDL files.
    public static final String QUERY_WSDL_LOCATION = "/Users/roy_antonyraj/" +
            "Documents/intellij-workspaces/vip-metro-sample/extras/wsdls/" +
            "vipuserservices-query-1.3.wsdl";

    public static void main(String[] args) throws MalformedURLException {
        // Step 1: Create an SSL Context.
        SSLContextFactory sslContextFactory = new SSLContextFactory();

        sslContextFactory.setKeyStorePath(KEY_STORE_PATH);
        sslContextFactory.setKeyStorePassword(KEY_STORE_PASSWORD);
        sslContextFactory.setPerformStrictNameMatching(false);
        sslContextFactory.init();

        SSLContext sslContext = sslContextFactory.getSSLContext();

        // Step 2: Create the service and set up the SSL context.
        QueryService queryService = new QueryService(new File(QUERY_WSDL_LOCATION).toURI().toURL());
        QueryServicePort queryServicePort = queryService.getQueryServicePort();
        BindingProvider bindingProvider = (BindingProvider)queryServicePort;
        bindingProvider.getRequestContext().put(BindingProvider.ENDPOINT_ADDRESS_PROPERTY,
                QUERY_SERVICE_URL);
        bindingProvider.getRequestContext().put(JAXWSProperties.SSL_SOCKET_FACTORY, sslContext
                .getSocketFactory());

        // Step 3: Send the request.
        GetServerTimeRequestType getServerTimeRequest = new GetServerTimeRequestType();
        // Always prefix request ID with a unique string that identifies your org.
        // Also make sure the request ID is unique so that troubleshooting is easier.
        String requestId = "MYORG_JVM1_" + System.currentTimeMillis();
        getServerTimeRequest.setRequestId(requestId);

        logger.info("Sending GetServerTime request with request ID [" + requestId + "]");
        GetServerTimeResponseType getServerTimeResponse = queryServicePort.getServerTime
                (getServerTimeRequest);

        // Log the response. Make sure the detail and detailMessages are logged when the status
        // is not success.
        logger.info("getServerTimeResponse.getStatus() = " + new BigInteger(getServerTimeResponse
                .getStatus()).toString(16));
        logger.info("getServerTimeResponse.getStatusMessage() = " + getServerTimeResponse
                .getStatusMessage());
        logger.info("getServerTimeResponse.getDetail() = " + getServerTimeResponse.getDetail());
        logger.info("getServerTimeResponse.getDetailMessage() = " + getServerTimeResponse
                .getDetailMessage());
        logger.info("getServerTimeResponse.getTimestamp() = " + getServerTimeResponse
                .getTimestamp());
    }


}
